@@ -1,3 +1,21 @@
+class RequestHeaders(object):
+    def __init__(self, headers: dict):
+        self.this = headers
+
+    def __getattr__(self, key: str):
+        """convert snake_cased headers to dashed and retrieve from headers dict
+        """
+        key = key.encode() if isinstance(key, str) else key
+
+        #ignore for custom x-headers NOTE to put this in documentation later...
+        k = key if key.lower().startswith(b'x-') else key.replace(b'_', b'-')
+        return self.this.get(k)
+
+    def get(self, key):
+        key = key.encode() if isinstance(key, str) else key
+        return self.this.get(key)
+
+
 class HttpRequest():
     def __init__(self, scope, body, receive):
         self._scope = scope
