@@ -1,10 +1,10 @@
 from unittest import TestCase
 
-from package import Router
-from package import Context
-from package import HttpRequest, ResponseWriter
+from routerling import Router
+from routerling import Context
+from routerling import HttpRequest, ResponseWriter
 
-from package.router import Routes
+from routerling.router import Routes
 
 
 # to be reused in router testcase instance
@@ -14,11 +14,6 @@ def handle_customer_created(r: HttpRequest, w: ResponseWriter, ctx: Context):...
 class TestRouter(TestCase):
     def setUp(self, *args, **kwargs):
         self.router = Router()
-        self.router.GET("/", def _(req, res, ctx): (
-            print("abcde"),
-            print("foryou"),
-            print("formetoo")
-        ))
         self.router.GET("/customers", handle_customer_created)
         self.router.GET("/customers/:id", handle_customer_created)
         self.router.GET("/customers/:id/orders", lambda r, w, c: (
